package net.sf.doolin.bus.bean;

import net.sf.doolin.util.BasicPropertySet;
import net.sf.sido.PropertyAccessor;

import org.apache.commons.lang.Validate;

public class BeanSet extends BasicPropertySet implements IBean {

	private final BeanNotificationSupport notificationSupport;
	private IParentBean parentBean;

	public BeanSet() {
		this(null, null);
	}

	public BeanSet(Object parent, String parentProperty) {
		super();
		this.notificationSupport = new BeanNotificationSupport(this);
		Validate.isTrue(!(parent == null ^ parentProperty == null));
		if (parent != null) {
			this.parentBean = new ParentBean(parent, parentProperty);
		} else {
			this.parentBean = null;
		}
	}

	@Override
	protected PropertyAccessor createPropertySet(PropertyAccessor parentSet,
			String nameInParent) {
		return new BeanSet(parentSet, nameInParent);
	}

	@Override
	public BeanNotificationSupport getBeanNotificationSupport() {
		return this.notificationSupport;
	}

	@Override
	public IParentBean getParentBean() {
		return this.parentBean;
	}

	@Override
	public void setParentBean(IParentBean parentBean) {
		this.parentBean = parentBean;
	}

	@Override
	protected void setSimple(String name, Object value) {
		Object old = getSimple(name);
		super.setSimple(name, value);
		// Notification
		this.notificationSupport.notify(name, old, value);
	}

}
