package net.sf.doolin.bus.bean;

import net.sf.sido.PropertyAccessor;

import org.apache.commons.beanutils.LazyDynaBean;
import org.apache.commons.lang.Validate;

public class BusDynaBean extends LazyDynaBean implements IBean, PropertyAccessor {

	private static final long serialVersionUID = 1L;

	private final BeanNotificationSupport notificationSupport;
	private IParentBean parentBean;

	public BusDynaBean() {
		this(null, null);
	}

	public BusDynaBean(Object parent, String parentProperty) {
		super();
		this.notificationSupport = new BeanNotificationSupport(this);
		Validate.isTrue(!(parent == null ^ parentProperty == null));
		if (parent != null) {
			this.parentBean = new ParentBean(parent, parentProperty);
		} else {
			this.parentBean = null;
		}
	}

	@Override
	public BeanNotificationSupport getBeanNotificationSupport() {
		return this.notificationSupport;
	}

	@Override
	public IParentBean getParentBean() {
		return this.parentBean;
	}

	@Override
	public Object getValue(String propertyPath) {
		return get(propertyPath);
	}

	@Override
	protected boolean isDynaProperty(String name) {
		return false;
	}

	@Override
	public void setParentBean(IParentBean parentBean) {
		this.parentBean = parentBean;
	}

	@Override
	public PropertyAccessor setValue(String name, Object value) {
		Object old = get(name);
		set(name, value);
		// Notification
		this.notificationSupport.notify(name, old, value);
		// OK
		return this;
	}
}
