package net.sf.doolin.bus.bean;

/**
 * This class defines the relationship between a {@link Bean} and its parent in
 * an object hierarchy.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ParentBean implements IParentBean {

	private final Object parent;
	private final String propertyInParent;

	/**
	 * Constructor for the association between a parent and the property that
	 * contains the child.
	 * 
	 * @param parent
	 *            Reference to the parent bean
	 * @param propertyInParent
	 *            Property in the parent that contains the child bean
	 */
	public ParentBean(Object parent, String propertyInParent) {
		this.parent = parent;
		this.propertyInParent = propertyInParent;
	}

	/**
	 * Notifies the change of the child from the parent level
	 * 
	 * @param propertyName
	 *            Property in the child
	 * @param oldValue
	 *            Old value for this property
	 * @param newValue
	 *            New value for this property
	 */
	@Override
	public void notifyForChild(String propertyName, Object oldValue,
			Object newValue) {
		if (this.parent instanceof IBean) {
			BeanNotificationSupport parentSupport = ((IBean) this.parent)
					.getBeanNotificationSupport();
			String propertyPath = this.propertyInParent + "." + propertyName;
			parentSupport.notify(propertyPath, oldValue, newValue);
		}
	}

}
