package net.sf.doolin.bus.cglib;


import net.sf.cglib.proxy.Enhancer;
import net.sf.doolin.bus.bean.BeanNotificationSupport;
import net.sf.doolin.bus.bean.IBean;
import net.sf.jstring.LocalizableException;


public class BeanProxyFactory {

	/**
	 * Creates a proxy from a class, by using a default constructor and
	 * annotations on the method. Calling <code>create(MyType.class)</code> is
	 * equivalent to call
	 * <code>proxy(new MyType(), BeanProxyDetection.ANNOTATION)</code>.
	 */
	public static <T> T create(Class<T> type) {
		try {
			T instance = type.newInstance();
			return BeanProxyFactory.proxy(instance);
		} catch (Exception ex) {
			throw new LocalizableException("ModelFactory.cannotCreateModel", ex, type
					.getName());
		}
	}

	public static <T> T proxy(final T instance) {
		// Creates the enhancer
		Enhancer enhancer = new Enhancer();
		// Class
		enhancer.setSuperclass(instance.getClass());
		enhancer.setInterfaces(new Class[] { IBean.class });

		// Callback
		BeanMethodInterceptor<T> interceptor = new BeanMethodInterceptor<T>(
				instance);
		enhancer.setCallback(interceptor);
		// Creates the instance
		@SuppressWarnings("unchecked")
		T proxy = (T) enhancer.create();
		// Notification support
		interceptor.getSupport().set(new BeanNotificationSupport(proxy));
		// OK
		return proxy;
	}
}
