package net.sf.doolin.bus.subscriber;

import net.sf.doolin.bus.Bus;
import net.sf.doolin.bus.Subscriber;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Subscriber that accepts all messages and logs them.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class LogSubscriber implements Subscriber<Object> {

	private static final Logger log = LoggerFactory
			.getLogger(LogSubscriber.class);

	@Override
	public boolean accept(Object message) {
		return true;
	}

	/**
	 * Unsubscribes this subscriber from the default bus.
	 */
	public void disable() {
		Bus.get().unsubscribe(this);
	}

	/**
	 * Enables this subscriber on the default bus.
	 */
	public void enable() {
		Bus.get().subscribe(this);
	}

	@Override
	public String getExecutionDescription() {
		return "Logs";
	}

	@Override
	public String getTriggerDescription() {
		return "Any message";
	}

	@Override
	public String getValidatorDescription() {
		return "Always";
	}

	@Override
	public boolean isValid() {
		return true;
	}

	@Override
	public void receive(Object message) {
		if (log.isDebugEnabled()) {
			log.debug(String.format("BUS %s", message));
		}
	}

}
