package net.sf.doolin.bus.support;

import net.sf.doolin.bus.Subscriber;

import org.apache.commons.lang.Validate;

/**
 * Abstract subscriber that relies on an external {@link SubscriberValidator}
 * for its validation.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <M>
 *            Type of message for this subscriber
 */
public abstract class AbstractSubscriber<M> implements Subscriber<M> {

	private SubscriberValidator validator = new DefaultSubscriberValidator();

	/**
	 * Builds a subscriber with the {@linkplain DefaultSubscriberValidator
	 * default validator}.
	 */
	public AbstractSubscriber() {
	}

	/**
	 * Builds a subscriber with a given validator.
	 * 
	 * @param validator
	 *            Validator to use for this subscriber.
	 */
	public AbstractSubscriber(SubscriberValidator validator) {
		Validate.notNull(validator, "Validator must not be null");
		this.validator = validator;
	}

	@Override
	public String getValidatorDescription() {
		return this.validator.getValidatorDescription();
	}

	@Override
	public boolean isValid() {
		return this.validator.isValid();
	}

}
