package net.sf.doolin.bus.support;

import net.sf.doolin.bus.BusLog;
import net.sf.doolin.bus.Priority;
import net.sf.doolin.bus.Subscriber;

/**
 * This {@link BusLog} implementation logs bus events using a text
 * representation. Subclasses are responsible for the actual logging of this
 * text.
 * 
 * @author Damien Coraboeuf
 * 
 */
public abstract class AbstractTextBusLog implements BusLog {

	@Override
	public <M> void messageAccepted(M message, Subscriber<M> subscriber) {
		log(String.format("%s accepted by %s", message, subscriber));
	}

	/**
	 * Actually logs the text message.
	 * 
	 * @param text
	 *            Text to log
	 */
	protected abstract void log(String text);

	@Override
	public void messageNoSubscription(Object message) {
		log(String.format("There is no subscription on the bus for message %s",
				message));
	}

	@Override
	public void messageReceived(Object message) {
		log(String.format("%s is received on the bus", message));
	}

	@Override
	public <M> void messageWithError(M message, Subscriber<M> subscriber,
			Throwable th) {
		log(String.format("Treatment of %s by %s has generated error %s",
				message, subscriber, th.getMessage()));
	}

	@Override
	public void registrationFailed(Subscriber<?> subscriber, Priority priority) {
		log(String.format("Registration of %s has failed", subscriber));
	}

	@Override
	public void registrationOk(Subscriber<?> subscriber, Priority priority) {
		log(String.format("Registration of %s with priority %s", subscriber,
				priority));
	}

	@Override
	public void unregistration(Subscriber<?> subscriber) {
		log(String.format("Unregistration of %s", subscriber));
	}

}
