package net.sf.doolin.bus.support;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import net.sf.doolin.util.Utils;

import org.apache.commons.lang.StringUtils;

/**
 * This validator performs a logical <code>and</code> between several
 * validators.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class AndSubscriberValidator implements SubscriberValidator {

	private List<SubscriberValidator> validators;

	/**
	 * Constructor with no validator.
	 */
	public AndSubscriberValidator() {
		this.validators = Collections.emptyList();
	}

	/**
	 * Constructor with a list of validators.
	 * 
	 * @param list
	 *            List of validators
	 */
	public AndSubscriberValidator(List<SubscriberValidator> list) {
		this.validators = list;
	}

	/**
	 * Constructor with an an array of validators
	 * 
	 * @param validatorArray
	 *            Array of validators
	 */
	public AndSubscriberValidator(SubscriberValidator... validatorArray) {
		this.validators = Arrays.asList(validatorArray);
	}

	@Override
	public String getValidatorDescription() {
		List<String> descriptions = Utils.convertToList(this.validators,
				"validatorDescription");
		return StringUtils.join(descriptions, " & ");
	}

	@Override
	public boolean isValid() {
		for (SubscriberValidator validator : this.validators) {
			boolean valid = validator.isValid();
			if (!valid) {
				return false;
			}
		}
		return true;
	}

	/**
	 * Sets the list of validators
	 * 
	 * @param validators
	 *            List of validators
	 */
	public void setValidators(List<SubscriberValidator> validators) {
		this.validators = validators;
	}

}
