package net.sf.doolin.bus.support;

import net.sf.doolin.bus.Subscriber;
import net.sf.doolin.bus.SubscriberExecution;
import net.sf.doolin.bus.SubscriberTrigger;

/**
 * This {@link Subscriber} delegates its methods to a
 * {@link SubscriberValidator}, a {@link SubscriberTrigger} and a
 * {@link SubscriberExecution}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <M>
 *            Type of message that is handled by this subscriber.
 */
public class SubscriberAdapter<M> implements Subscriber<M> {

	private final SubscriberValidator validator;
	private final SubscriberTrigger trigger;
	private final SubscriberExecution<M> execution;

	/**
	 * Constructor.
	 * 
	 * @param validator
	 *            The validator to use
	 * @param trigger
	 *            The trigger to use
	 * @param execution
	 *            The execution to use
	 */
	public SubscriberAdapter(SubscriberValidator validator,
			SubscriberTrigger trigger, SubscriberExecution<M> execution) {
		this.execution = execution;
		this.trigger = trigger;
		this.validator = validator;
	}

	@Override
	public boolean accept(Object message) {
		return this.trigger == null || this.trigger.accept(message);
	}

	@Override
	public String getExecutionDescription() {
		return this.execution != null ? this.execution
				.getExecutionDescription() : "None";
	}

	@Override
	public String getTriggerDescription() {
		return this.trigger != null ? this.trigger.getTriggerDescription()
				: "None";
	}

	@Override
	public String getValidatorDescription() {
		return this.validator != null ? this.validator
				.getValidatorDescription() : "None";
	}

	@Override
	public boolean isValid() {
		return this.validator == null || this.validator.isValid();
	}

	@Override
	public void receive(M message) {
		if (this.execution != null) {
			this.execution.receive(message);
		}
	}

}
