package net.sf.doolin.bus.support;

import net.sf.doolin.bus.bean.Bean;

/**
 * Value handler that extends the {@link Bean} class.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            type of handled value
 */
public class Value<T> extends Bean {

	private static final long serialVersionUID = 1L;

	private T value;

	/**
	 * Constructor with an initial <code>null</code> value.
	 */
	public Value() {
	}

	/**
	 * Constructor with an initial value.
	 * 
	 * @param initialValue
	 *            Initial value to set.
	 */
	public Value(T initialValue) {
		this.value = initialValue;
	}

	/**
	 * Gets the current value
	 * 
	 * @return Current value
	 */
	public T getValue() {
		return this.value;
	}

	/**
	 * Sets the current value
	 * 
	 * @param value
	 *            Current value to set
	 */
	public void setValue(T value) {
		notify("value", this.value, this.value = value);
	}

}
